@@ -85,6 +85,23 @@ class RestartTest extends BaseTestCase
         $this->checkRestart($xdebug);
     }
 
+    public function testNoRestartWithUnexpectedArgv(): void
+    {
+        $loaded = true;
+
+        $_SERVER['argv'] = false;
+        $xdebug = CoreMock::createAndCheck($loaded);
+        $this->checkNoRestart($xdebug);
+
+        $_SERVER['argv'] = [];
+        $xdebug = CoreMock::createAndCheck($loaded);
+        $this->checkNoRestart($xdebug);
+
+        $_SERVER['argv'] = [1, 2];
+        $xdebug = CoreMock::createAndCheck($loaded);
+        $this->checkNoRestart($xdebug);
+    }
+
     /**
      * @dataProvider unreachableScriptProvider
      */
@@ -101,7 +118,7 @@ class RestartTest extends BaseTestCase
     /**
      * @return array<string[]>
      */
-    public function unreachableScriptProvider(): array
+    public static function unreachableScriptProvider(): array
     {
         return [
             ['nonexistent.php'],
@@ -132,9 +149,10 @@ class RestartTest extends BaseTestCase
     /**
      * @return array<string[]>
      */
-    public function scriptSetterProvider(): array
+    public static function scriptSetterProvider(): array
     {
         return [
+            // @phpstan-ignore-next-line
             [(string) realpath($_SERVER['argv'][0])],
             ['--'],
         ];
