@@ -28,7 +28,7 @@ class SettingsTest extends BaseTestCase
      * @param string $iniFunc IniHelper method to use
      * @param false|string $scanDir Initial value for PHP_INI_SCAN_DIR
      * @param false|string $phprc Initial value for PHPRC
-     * @dataProvider environmentProvider     *
+     * @dataProvider environmentProvider
      */
     public function testGetRestartSettings(string $iniFunc, $scanDir, $phprc): void
     {
@@ -54,7 +54,7 @@ class SettingsTest extends BaseTestCase
     /**
      * @phpstan-return envTestData
      */
-    public function environmentProvider(): array
+    public static function environmentProvider(): array
     {
         return EnvHelper::dataProvider();
     }
