@@ -9,29 +9,23 @@
  * the LICENSE file that was distributed with this source code.
  */
 
+declare(strict_types=1);
+
 namespace Composer\XdebugHandler\Tests;
 
 use Composer\XdebugHandler\Tests\Helpers\BaseTestCase;
-use Composer\XdebugHandler\Tests\Helpers\LoggerFactory;
+use Composer\XdebugHandler\Tests\Helpers\Logger;
 use Composer\XdebugHandler\Tests\Mocks\CoreMock;
 use Psr\Log\LogLevel;
 
-/**
- * We use PHP_BINARY which only became available in PHP 5.4
- *
- * @requires PHP 5.4
- */
 class StatusTest extends BaseTestCase
 {
-    /**
-     * @return void
-     */
-    public function testSetLoggerProvidesOutput()
+    public function testSetLoggerProvidesOutput(): void
     {
         $loaded = true;
 
-        $logger = LoggerFactory::createLogger();
-        $settings = array('setLogger' => array($logger));
+        $logger = new Logger();
+        $settings = ['setLogger' => [$logger]];
 
         $xdebug = CoreMock::createAndCheck($loaded, null, $settings);
         $this->checkRestart($xdebug);
